@@ -339,9 +339,9 @@ class _RealTimeJsonEventPicker:
 
     def send_api_call(self,json_data):
         headers = {'Content-Type': 'application/json'}
-        API_URL = "https://monthly-genuine-troll.ngrok-free.app" #https://matricedemo.forumalertcloud.io/matriceapi/
-        API_USER = "admin" #"matrice"
-        API_PASS = "admin" #"hR9aN9mQ"
+        API_URL = "https://matricedemo.forumalertcloud.io/matriceapi/" #"https://monthly-genuine-troll.ngrok-free.app" #https://matricedemo.forumalertcloud.io/matriceapi/
+        API_USER = "matrice" #"admin" #"matrice"
+        API_PASS = "hR9aN9mQ" #"admin" #"hR9aN9mQ"
         try:
             response = requests.post(
             API_URL,
