@@ -6,6 +6,8 @@ post-processing scenarios.
 """
 
 from .people_counting import PeopleCountingUseCase, PeopleCountingConfig
+from .intrusion_detection import IntrusionUseCase, IntrusionConfig
+from .proximity_detection import ProximityUseCase, ProximityConfig
 from .customer_service import CustomerServiceUseCase, CustomerServiceConfig
 from .advanced_customer_service import AdvancedCustomerServiceUseCase
 from .basic_counting_tracking import BasicCountingTrackingUseCase
@@ -68,8 +70,11 @@ from .face_recognition import FaceRecognitionConfig, FaceRecognitionUseCase
 from .drowsy_driver_detection import DrowsyDriverUseCase, DrowsyDriverUseCase
 from .waterbody_segmentation import WaterBodyConfig, WaterBodyUseCase
 from .litter_monitoring import LitterDetectionConfig,LitterDetectionUseCase
+from .abandoned_object_detection import AbandonedObjectConfig,AbandonedObjectDetectionUseCase
+
+from .litter_monitoring import LitterDetectionConfig, LitterDetectionUseCase
 from .leak_detection import LeakDetectionConfig, LeakDetectionUseCase
-from .human_activity import HumanActivityConfig, HumanActivityUseCase
+from .human_activity_recognition import HumanActivityConfig, HumanActivityUseCase
 from .gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 
 #Put all IMAGE based usecases here
@@ -81,6 +86,8 @@ from .Histopathological_Cancer_Detection_img import HistopathologicalCancerDetec
 
 __all__ = [
     'PeopleCountingUseCase',
+    'IntrusionUseCase',
+    'ProximityUseCase',
     'CustomerServiceUseCase',
     'AdvancedCustomerServiceUseCase',
     'BasicCountingTrackingUseCase',
@@ -136,6 +143,7 @@ __all__ = [
     'DrowsyDriverUseCase',
     'WaterBodyUseCase',
     'LitterDetectionUseCase',
+    'AbandonedObjectDetectionUseCase',
     'LeakDetectionUseCase',
     'HumanActivityUseCase',
     'GasLeakDetectionUseCase',
@@ -150,6 +158,8 @@ __all__ = [
 
 
     'PeopleCountingConfig',
+    'IntrusionConfig',
+    'ProximityConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
     'AdvancedCustomerServiceConfig',
@@ -204,6 +214,8 @@ __all__ = [
     'DrowsyDriverUseCase',
     'WaterBodyConfig',
     'LitterDetectionConfig',
+    'AbandonedObjectConfig',
+
     'LeakDetectionConfig',
     'HumanActivityConfig',
     'GasLeakDetectionConfig',
